@@ -836,7 +836,7 @@ environment variables are expanded recursively, so if you use::
 The value of MYVAR2 will be :code:`a/<path to home directory>/b`.
 '''))
 
-o('update_check_interval', 24, option_type=float, long_text=_('''
+o('update_check_interval', 0.0, option_type=float, long_text=_('''
 Periodically check if an update to kitty is available. If an update is found
 a system notification is displayed informing you of the available update.
 The default is to check every 24 hrs, set to zero to disable.
